@@ -40,7 +40,9 @@ where
     /// Write a byte of data to a register.
     fn write_byte(&mut self, register: Register, value: &u8) -> Result<(), I2C::Error> {
         let register_data = [register.into(), *value];
-        self.i2c.write_read(self.address, &register_data, &mut [] as &mut [u8])
+        // The grideye gets angry if there's a 0-length read, so read a byte, and do nothing with it
+        let mut dummy = [0u8];
+        self.i2c.write_read(self.address, &register_data, &mut dummy)
     }
 
     /// Read a byte of data from a register.
